# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service/service_spec/glurpc.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'service/service_spec/glurpc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!service/service_spec/glurpc.proto\x12\x06glurpc\"/\n\x17\x43onvertToUnifiedRequest\x12\x14\n\x0c\x66ile_content\x18\x01 \x01(\x0c\">\n\x18\x43onvertToUnifiedResponse\x12\x13\n\x0b\x63sv_content\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"D\n\x15ProcessUnifiedRequest\x12\x12\n\ncsv_base64\x18\x01 \x01(\t\x12\x17\n\x0f\x66orce_calculate\x18\x02 \x01(\x08\"r\n\x16ProcessUnifiedResponse\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x15\n\rtotal_samples\x18\x02 \x01(\x05\x12\"\n\x08warnings\x18\x03 \x01(\x0b\x32\x10.glurpc.Warnings\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xae\x01\n\x08Warnings\x12\x14\n\x0chas_warnings\x18\x01 \x01(\x08\x12\x11\n\ttoo_short\x18\x02 \x01(\x08\x12\x13\n\x0b\x63\x61libration\x18\x03 \x01(\x08\x12\x0f\n\x07quality\x18\x04 \x01(\x08\x12\x12\n\nimputation\x18\x05 \x01(\x08\x12\x14\n\x0cout_of_range\x18\x06 \x01(\x08\x12\x17\n\x0ftime_duplicates\x18\x07 \x01(\x08\x12\x10\n\x08messages\x18\x08 \x03(\t\"E\n\x0bPlotRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x17\n\x0f\x66orce_calculate\x18\x03 \x01(\x08\"0\n\x0cPlotResponse\x12\x11\n\tplot_json\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"?\n\x10QuickPlotRequest\x12\x12\n\ncsv_base64\x18\x01 \x01(\t\x12\x17\n\x0f\x66orce_calculate\x18\x02 \x01(\x08\"Y\n\x11QuickPlotResponse\x12\x11\n\tplot_json\x18\x01 \x01(\t\x12\"\n\x08warnings\x18\x02 \x01(\x0b\x32\x10.glurpc.Warnings\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"8\n\x16\x43\x61\x63heManagementRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\t\"\x80\x01\n\x17\x43\x61\x63heManagementResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\ncache_size\x18\x03 \x01(\x05\x12\x17\n\x0fpersisted_count\x18\x04 \x01(\x05\x12\x16\n\x0eitems_affected\x18\x05 \x01(\x05\"\x0f\n\rHealthRequest\"\x90\x06\n\x0eHealthResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0bload_status\x18\x02 \x01(\t\x12\x12\n\ncache_size\x18\x03 \x01(\x05\x12\x1a\n\x12models_initialized\x18\x04 \x01(\x08\x12!\n\x19\x61vailable_priority_models\x18\x05 \x01(\x05\x12 \n\x18\x61vailable_general_models\x18\x06 \x01(\x05\x12\x1f\n\x17\x61vg_fulfillment_time_ms\x18\x07 \x01(\x01\x12\x15\n\rvmem_usage_mb\x18\x08 \x01(\x01\x12\x0e\n\x06\x64\x65vice\x18\t \x01(\t\x12\x1b\n\x13total_http_requests\x18\n \x01(\x05\x12\x19\n\x11total_http_errors\x18\x0b \x01(\x05\x12\x1b\n\x13\x61vg_request_time_ms\x18\x0c \x01(\x01\x12\x1e\n\x16median_request_time_ms\x18\r \x01(\x01\x12\x1b\n\x13min_request_time_ms\x18\x0e \x01(\x01\x12\x1b\n\x13max_request_time_ms\x18\x0f \x01(\x01\x12_\n\x1einference_requests_by_priority\x18\x10 \x03(\x0b\x32\x37.glurpc.HealthResponse.InferenceRequestsByPriorityEntry\x12\x1e\n\x16total_inference_errors\x18\x11 \x01(\x05\x12\x17\n\x0ftotal_calc_runs\x18\x12 \x01(\x05\x12\x19\n\x11total_calc_errors\x18\x13 \x01(\x05\x12\x1c\n\x14inference_queue_size\x18\x14 \x01(\x05\x12 \n\x18inference_queue_capacity\x18\x15 \x01(\x05\x12\x17\n\x0f\x63\x61lc_queue_size\x18\x16 \x01(\x05\x12\x1b\n\x13\x63\x61lc_queue_capacity\x18\x17 \x01(\x05\x1a\x42\n InferenceRequestsByPriorityEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x32\xce\x03\n\x11GlucosePrediction\x12W\n\x10\x43onvertToUnified\x12\x1f.glurpc.ConvertToUnifiedRequest\x1a .glurpc.ConvertToUnifiedResponse\"\x00\x12Q\n\x0eProcessUnified\x12\x1d.glurpc.ProcessUnifiedRequest\x1a\x1e.glurpc.ProcessUnifiedResponse\"\x00\x12\x37\n\x08\x44rawPlot\x12\x13.glurpc.PlotRequest\x1a\x14.glurpc.PlotResponse\"\x00\x12\x42\n\tQuickPlot\x12\x18.glurpc.QuickPlotRequest\x1a\x19.glurpc.QuickPlotResponse\"\x00\x12P\n\x0bManageCache\x12\x1e.glurpc.CacheManagementRequest\x1a\x1f.glurpc.CacheManagementResponse\"\x00\x12>\n\x0b\x43heckHealth\x12\x15.glurpc.HealthRequest\x1a\x16.glurpc.HealthResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service.service_spec.glurpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEALTHRESPONSE_INFERENCEREQUESTSBYPRIORITYENTRY']._loaded_options = None
  _globals['_HEALTHRESPONSE_INFERENCEREQUESTSBYPRIORITYENTRY']._serialized_options = b'8\001'
  _globals['_CONVERTTOUNIFIEDREQUEST']._serialized_start=45
  _globals['_CONVERTTOUNIFIEDREQUEST']._serialized_end=92
  _globals['_CONVERTTOUNIFIEDRESPONSE']._serialized_start=94
  _globals['_CONVERTTOUNIFIEDRESPONSE']._serialized_end=156
  _globals['_PROCESSUNIFIEDREQUEST']._serialized_start=158
  _globals['_PROCESSUNIFIEDREQUEST']._serialized_end=226
  _globals['_PROCESSUNIFIEDRESPONSE']._serialized_start=228
  _globals['_PROCESSUNIFIEDRESPONSE']._serialized_end=342
  _globals['_WARNINGS']._serialized_start=345
  _globals['_WARNINGS']._serialized_end=519
  _globals['_PLOTREQUEST']._serialized_start=521
  _globals['_PLOTREQUEST']._serialized_end=590
  _globals['_PLOTRESPONSE']._serialized_start=592
  _globals['_PLOTRESPONSE']._serialized_end=640
  _globals['_QUICKPLOTREQUEST']._serialized_start=642
  _globals['_QUICKPLOTREQUEST']._serialized_end=705
  _globals['_QUICKPLOTRESPONSE']._serialized_start=707
  _globals['_QUICKPLOTRESPONSE']._serialized_end=796
  _globals['_CACHEMANAGEMENTREQUEST']._serialized_start=798
  _globals['_CACHEMANAGEMENTREQUEST']._serialized_end=854
  _globals['_CACHEMANAGEMENTRESPONSE']._serialized_start=857
  _globals['_CACHEMANAGEMENTRESPONSE']._serialized_end=985
  _globals['_HEALTHREQUEST']._serialized_start=987
  _globals['_HEALTHREQUEST']._serialized_end=1002
  _globals['_HEALTHRESPONSE']._serialized_start=1005
  _globals['_HEALTHRESPONSE']._serialized_end=1789
  _globals['_HEALTHRESPONSE_INFERENCEREQUESTSBYPRIORITYENTRY']._serialized_start=1723
  _globals['_HEALTHRESPONSE_INFERENCEREQUESTSBYPRIORITYENTRY']._serialized_end=1789
  _globals['_GLUCOSEPREDICTION']._serialized_start=1792
  _globals['_GLUCOSEPREDICTION']._serialized_end=2254
# @@protoc_insertion_point(module_scope)
